@@ -1,4 +1,4 @@
-# $Id: Default.pm 3 2009-03-03 19:13:39Z jo $
+# $Id: Default.pm 120 2013-01-31 11:34:41Z jo $
 # Cindy::Log - Logging for Cindy
 #
 # Copyright (c) 2008 Joachim Zobel <jz-2008@heute-morgen.de>. All rights reserved.
@@ -18,19 +18,19 @@ our @EXPORT= qw(DEBUG INFO WARN ERROR FATAL);
 
 use Carp;
 
-sub ERROR ($)
+sub ERROR 
 {
   croak @_;
 }
 
-sub WARN ($)
+sub WARN 
 {
   carp @_;
 }
 
-sub INFO($) {}
+sub INFO {}
 
-sub DEBUG($) {}
+sub DEBUG {}
 
 1;
 
